==> spellathon-5.59.tar.gz: spellathon-5.59/src/logic/defines.h <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef	DEFINE_H
#define	DEFINE_H

#define	MAX_LETRS		7		/* don't change */
#define	MIN_LETRS		4		/* don't change */
#define	NCOMBINATIONS	42		/* don't change */

#define MAX_SOL			24		/* defaults */
#define MIN_SOL			3
#define MMAX_SOL		999		/* hard limits */
#define MMIN_SOL		1	
#define MGAP_SOL		0		/* minimum (MAX_SOL - MIN_SOL) */

const char* const Ratings[4] = { "", "Average", "Good", "Outstanding" };	
const int Scores[4] = { 0, 20, 50, 75 };

const int HintPenalty[2] = { 13, 26 };

const int TimePenalty = 7;
const int No7Penalty = 7;

#define PRECOMP		false		
#define PLURAL_SIEVE true		

#ifndef DICTPATH
# define DICTPATH	"dict/words.txt"
#endif /* DICTPATH */

#define	DICTBIN		"spellathon.dat"

#define MAGIC		"Spellathon"

#define VERSION		"5.59"

#endif /* DEFINE_H */

==> spellathon-5.72.tar.gz: spellathon-5.72/src/logic/defines.h <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef	DEFINE_H
#define	DEFINE_H

#define	MAX_LETRS		7		/* don't change */
#define	MIN_LETRS		4		/* don't change */
#define	NCOMBINATIONS		42		/* don't change */
#define SOLVER_MAX_WORDS	1024		/* max word array size used in solver(). */

/* defaults */
#define MAX_SOL			24		
#define MIN_SOL			3
/* hard limits */
#define MMAX_SOL		999		/* must be <= SOLVER_MAX_WORDS */
#define MMIN_SOL		1	
#define MGAP_SOL		0		/* minimum (MAX_SOL - MIN_SOL) */

const char* const Ratings[4] = { "", "Average", "Good", "Outstanding" };	
const int Scores[4] = { 0, 20, 50, 75 };

const int HintPenalty[2] = { 13, 26 };

const int TimePenalty = 7;
const int No7Penalty = 7;

#define PRECOMP		false		
#define PLURAL_SIEVE true		

#ifndef DICTPATH
# define DICTPATH	"dict/words.txt"
#endif /* DICTPATH */

#define	DICTBIN		"spellathon.dat"

#define MAGIC		"Spellathon"

#define VERSION		"5.72"

#endif /* DEFINE_H */
